pub enum ReceiptRole {
Input,
Output,
Auxiliary,
}Expand description
Logical role of a file in a dataset operation.
Variants
Input
File consumed by an operation.
Output
File produced by an operation.
Auxiliary
File associated with an operation but not consumed or produced by it.